#
# spec file for package python-pymisp
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{!?license: %global license %doc}
Name:           python-pymisp
Version:        2.4.102
Release:        2.7
Summary:        Python API for MISP
License:        BSD-2-Clause
Group:          Development/Languages/Python
Url:            https://github.com/MISP/PyMISP
Source:         https://files.pythonhosted.org/packages/source/p/pymisp/pymisp-%{version}.tar.gz
# Internal script for generating changelog
Source1:        changelog.sh
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION tests
BuildRequires:  %{python_module jsonschema}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module python-magic}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module requests}
BuildRequires:  python2-enum34
# /SECTION
# SECTION docs
BuildRequires:  python3-CommonMark
BuildRequires:  python3-Sphinx
BuildRequires:  python3-recommonmark
# /SECTION
Requires:       python-jsonschema
Requires:       python-python-dateutil
Requires:       python-requests
%ifpython2
Requires:       python2-enum34
%endif
Recommends:     %{name}-doc
Recommends:     python-magic
Suggests:       python-pydeep
BuildArch:      noarch

%python_subpackages

%package -n %{name}-doc
Summary:        Examples and Documentation for %{name}
Group:          Documentation/HTML

%description
PyMISP is a Python library to access MISP platforms via their REST API.

PyMISP allows you to fetch events, add or update events/attributes, add or update samples or search for attributes.

%description -n %{name}-doc
Examples and HTML documentation for %{name}.

%prep
%setup -q -n pymisp-%{version}
find pymisp examples -name "*.py" -type f -exec sed -i '1s/^#!.*//' '{}' \+

%build
%python_build
pushd docs
export LANG=en_US.UTF-8
make html
rm build/html/.buildinfo
popd

%install
%python_install
%{python_expand %fdupes %{buildroot}%{$python_sitelib}}

%check
# Requires internet access and a MISP-instance
rm tests/test.py
%python_exec setup.py test

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/*

%files -n %{name}-doc
%doc examples docs/build/html

%changelog
* Sun Feb  3 2019 sebix+novell.com@sebix.at
- update to version 2.4.102:
  - New
  - Add test cases for stix export.
  - Changes
  - [datamodel] new anonymised type added.
  - [data] types updated to include the new zeek type.
  - Other
  - Check if IOC values are in warninglist.
- update to version 2.4.101:
  - New
  - Add missing test case for NOT on attribute level, update Pipfile.
  - Add support for unix timestamp in set_date.
    fix #302
  - Add test for references when adding/updating a full event.
  - [usersStats] Possibility to fetch users/statistics data for all
    context (usage, org, tags, ...)
  - Changes
  - Force to_ids to be a boolean, as MISP is expecting.
    fix #320
  - Add support for sharing group filter for search_index.
  - Support for Payload Delivery > Other attribute as PyMISP function.
  - Add Pipfile config.
  - [data] fix describeTypes.
  - [data] new types added (hassh-md5 and hasshserver-md5)
  - Bump misp-objects.
  - [misp-objects] templates updated to the latest version.
  - [data] describeTypes updated (grabbed from MISP HEAD)
  - [data] ja3-fingerprint-md5 type added.
  - [test] set a default distribution for massive event creation.
  - [data] describeTypes.json updated to the latest version.
  - More flexibility when loading an object from python dict.
  - Pass all parameters to the search API.
  - Remove compat for MISP 2.4.52, cleanup.
  - Set verifycert to false in tests.
  - [tests] Added verifycert option in case of using self-signed cert.
  - Fix
  - Remove jupyter & ipython from dev install so it works with python2.
  - Wrong variable name in MISPEvent.
  - Documentation error fix #278.
  - Attempt to fix memory footprint in MISPAttribute.
  - Still support simple event dict content.
  - Don't modify event passed to the add_attribute methods.
    fix #321
  - The wrong class name was used when there is an error at Event
    creation.
  - Use new API in get_csv.py.
    Fix #314
  - Test case was broken.
  - Create massive event using ExpandedPyMISP.
  - Error vs errors key.
  - Typo.
  - Get_object_template_id.
  - Other
  - Update pymisp tutorial.
    Extract the "response" field from the json result returned by misp.search_index
  - Sort describeTypes.json output.
    This is needed for the compatibility with the gen_misp_types_categories.py script. Data was sorted using the order_dict function of the gen_misp_types_categories script.
* Sun Jan 27 2019 sebix+novell.com@sebix.at
- Update to version 2.4.99:
  - New
  - Auto generate doc for PyMISPExpanded.
  - Search_index in ExpandedPyMISP, cleanup, update jupyter.
  - Add log search.
  - Add test for pushing an event to ZMQ.
  - Change_distribution method.
  - Add test cases for sightings, cleanup.
  - [example] Added sighting rest search example.
  - [sighting] Added support of sighting REST API.
  - Allow to pass csv to return_format in search.
  - Page/limit in search.
  - Changes
  - Add test cases for default distribution levels.
  - Include proposals in attributes search.
    Add includeProposals param to the search method
  - Update readme to document testing.
  - Fixes & update Jupyter.
  - [tuto] Update search.
  - Add a script to load the API key from the file system (training VM)
  - Add print in testlive to debug travis.
  - Fix
  - Auto generate doc for PyMISPExpanded.
  - Properly handle errors on event creation/update.
  - Test case.
  - Do not run the zmq test on travis.
  - Type of quick_filter.
  - Quick_filter was broken.
  - Properly initialize the config when jupyter runs on the VM.
  - Readme update + python3 + pep8.
    align python path to readme specifying python3
  - Feed-generator gitignore.
  - Test cases.
  - Other
  - Dded get_object & get_attribute.
  - Fix for last pymisp version.
  - Mention virtualenv.
    mide make sense for people who want to use it with virtualenv
  - Be more precise with the supported time indicators.
  - Fixed documentation bug.
  - Fixes date parameters for search_index() function.
  - Align examples on custom usage of misp_verifycert.
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Sun Oct 14 2018 sebix+novell.com@sebix.at
- Remove fix-274.patch and fix-274-1.patch.
- update to version 2.4.96:
  - New
  - [freedFromRedis] try to create an object/attribute out of the incoming
    data even if not added with the helper.
  - Direct_call without data means GET.
  - Add direct call to just post data on a URL.
  - Update warninglists.
  - Toggle warning list, add test case.
  - Add lots of test cases, find lots of bugs.
  - Use new CSV interface, add test cases.
  - Changes
  - Allow to pass a json string to direct_call.
  - Update order parameters & doc.
  - Add an extra IP from the warninglists.
  - Fix
  - Prevent checking length on a integer.
  - Use proper dependency (enum34)
  - Other
  - Fixed leaked taxonomy tags problem.
  - Added some getters and setters for taxonomies, warninglists,
    noticelists and tags & documentation.
  - Add: Advanced Extraction to upload_sample.
  - Add: update noticelists and object templates.
  - Add: Add __eq__ to AbstractMISP.
    Allow to discard duplicate tags.
* Mon Sep 17 2018 sebix+novell.com@sebix.at
- Add fix-274.patch and fix-274-1.patch to fix missing enum library (#274).
- update to version v2.4.95 (2018-09-06):
  - New
  - Add helpers for new server related APIs.
  Fix #266
  - Reworking the REST API (WiP)
  - Add Jupyter for search.
  - Changes
  - [data-model] updated describeTypes file.
  - Added email-header attribute.
  - Updated types/categories mapping.
  - Open all json files as bytes before loading in json.
  - [PyMISP] describeTypes.json updated to add XMR type.
  - Fix
  - Normalizing the outputs.
  - Jerry rig support for old python.
  - Format of the describeTypes.
  - [search.py] more example of query type added.
  - Properly validate the last-type search query.
  - Opening the json blobs as bytes was buggy.
  - Allow boolean parameters in search_index.
  - Typo in OpenIOC script.
  - Fix #237
  - Bad URL in get_attachment.
  - Fix #240
  - Improve error message in case the object template is unknown.
- update to version v2.4.93 (2018-07-01):
  - New
  - Add many comments in the jupyter notebook.
  - Return the new object in `add_object`
  - Add the ability to add Other attributes via the API.
  - Tuto for MISPEvent.
  - Load Org and Orgc as MISPOrganisation.
  - Related to #239
  - Changes
  - Moar jupyter.
  - Add few more calls.
  - Fix sample retrieval from new-style zips.
  - Raise an exception if the response is not in JSON.
- update to version v2.4.92.1 (2018-06-05):
  - Fix
  - Index out of range in add_object.
- update to version v2.4.92 (2018-06-05):
  - New
  - Add edit_object, simplify add_object.
  - Fix
  - Correct docstring of search method. [iso]
  - Response data type mismatch in _send_attributes()
  - Fix #206
  - Decoding issue.
* Thu May 10 2018 sebix+novell.com@sebix.at
- update to version 2.4.90.1:
  * New
  - Properly implement the Email object creator.
  * Changes
  - Normalize the RestResponse calls.
  * Fix
  - Properly get and decode the body of the email.
  - Provide the extension of the EML file to attach.
  - Properly handle attachments.
* Sun Apr 29 2018 sebix+novell.com@sebix.at
- update to version 2.4.90:
  * New
  - Add more feed management methods. Fix #221
  - Add update_attribute method.
  - Add event_timestamp to REST search. Fix #220
  - Add helper for Geolocation object.
  - Add helper for ASN object.
  - More flexibility in <something> -> datetime.
  - Add helper for DomainIP.
  - Add preliminary fail2ban object.
  * Changes
  - Add more examples.
  - Remove useless timestamp cleanup.
  - Make object helpers more generic, cleanup.
  - Update fail2ban helper & example.
  * Fix
  - Use the recommended approach to add an attribute.
  - Tests, new template version.
  - New key - extends_uuid.
  - Update test file accordingly to the default value.
  - Geolocation object filename.
  - Consider a timestamp < 30000000 as a date.
  - AbstractMISP.from_dict() do not accept positional argument.
  - Properly create fail2ban object.
  - Add Info field to the event.
  - Disable email object for python <3.6.
  * Other
  - Added missing field to feed generator.
  - Add the ability to add an Autonomous System(AS) via the API.
  - Changed shebang to python3.
  - Deleted remaining outputs.
  - First jupyter notebook tutorial (1 iterations)
  - Added change_analysis_status API.
  - Fix add_named_attribute regression, update add_named_attribute.py
    example.
  - Example of specifying special attribute type in your search: here yara
    attribute.
* Fri Mar 23 2018 sebix+novell.com@sebix.at
- update to 2.4.89:
  - Add email object generator.
  - Method to return an object by uuid.
  - Do not try to upload objects in case make_binary_objects fails. Realtime feed generator
  - Creation of the generator object which permit to easily add attributes and objects to daily events, stored as a MISP feed.
  - Added support of MISP Object.
  - Point to right anchor for client side certificates.
  - Add search on sighting.
  - Add attributes within objects as well, for tagging via value/id/uuid.
* Tue Feb 13 2018 sebix+novell.com@sebix.at
- update to version 2.4.87.1:
  - APIs to manage sharing groups. (#185)
  - ReturnMetaAttributes flag for freeTextImport API. (#188)
  - Encode string in _encode_file_to_upload.
  - Prevent unpublished events to be included in feed.
  Change default proposed config
- remove patch fix-Encode_string_in__encode_file_to_upload.patch, included upstream
* Tue Jan 30 2018 sebix+novell.com@sebix.at
- update to version 2.4.87:
  - Add bindings for Galaxies and Taxonimies.
  - Add bindings to PyMISPWarninglists.
  - Raise an exception when distribution is sharing group, but the ID is
  missing.
  - Allow to pass a directory with custom object templates.
  - Allow to pass value, UUID, or ID to a sighting.
  - Add_hashes was broken. (#174)
  - Add: Allow to fetch warninglists. (#180)
- Add fix-Encode_string_in__encode_file_to_upload.patch to fix encoding problem (#183)
* Fri Dec 22 2017 sebix+novell.com@sebix.at
- update to version 2.4.85:
  - Add last field to get_csv.
  - Validate attributes in attributes.setter.
  - Add get_attribute_tag method at MISPEvent level.
  Also add a MISPTag class for consistency.
  - Use new format for filtering.
  - Initialize default class parameters. (#155)
  - Fix MISPObject missing distribution and sharing_group_id.
  - fix MISPObject missing distribution concept
  - fix language typo paramaters => parameters
  - Include documentation and examples in source dist.
* Wed Dec 13 2017 sebix+novell.com@sebix.at
- update to version 2.4.84
  - Add methods to get taxonomy(ies)
  - Add method to get all the events modified in an interval.
  - Allow to pass a pseudofile to LIEF.
  - Correction for 'last' param. 'last' gives the latest events that
  have been published - add get_events_last_modified() this function
  returns the modified events based on timestamp.
* Thu Dec  7 2017 sebix+novell.com@sebix.at
- update to version 2.4.83
  - Add get CSV method.
  - Allow to pass a proxy to query VT.
  - Do not get the event from the server before publishing if
  PyMISP.publish gets an ID.
  - Add a way to check if the ACL is up-to-date.
  - Add validators for describeTypes on the live instance.
  - Add new objects: MISPUser and MISPOrganisation.
  - Add a generic MISP object generator.
  - Allow to add multiple attribute of the same type.
  - Add fast publish method. Fix #86
* Fri Nov 10 2017 sebix+novell.com@sebix.at
- update to version 2.4.82
  - Proper debug system.
  - Changes
  - Small improvments in the logging system using python logging module.
  - Let load unknown object relations in known templates.
  - Allow to load non-malware ZIP files in MISP Event.
  - Properly pass the distribution when uploading a sample.
  - Other
  - Created add_generic_object.py.
- remove patch fix-offline-test.patch, included in upstream version
- shorten existing changelogs
* Thu Oct 26 2017 sebix+novell.com@sebix.at
- update to version 2.4.81.2
- update to version 2.4.81.1:
  - Allow to hard delete an attribute by ID.
  - Fixes
  - Improve dependencies listing. Partial fix for #110
  - Missing default category. Fix #119
- add fix-offline-test.patch to fix tests
* Mon Oct  9 2017 sebix+novell.com@sebix.at
- update to version 2.4.81
* Wed Oct  4 2017 sebix+novell.com@sebix.at
- update to version 2.4.80.1
  - Fix
  - Allow again to tag/delete unsaved attributes.
  - Import the openioc converter from tool again.
  - Other
  - Fixing #114 (MISPEvent.add_tag(tag) fails if inital event does not contain tag )
  - Formatted "Unknown MISP object" error message.
- removed fix-tests-pr-111.patch, merged upstream
* Wed Sep 20 2017 sebix+novell.com@sebix.at
- update to version 2.4.80
  - Allow to get the list of known types out of MISPEvent again.
  - Changed two fields in object references.
  - source_uuid => object_uuid
  - destination_uuid => referenced_uuid
  - Refactoring in order to load objects.
  - Add support for multiple entries of the same type in an object.
  - Add support for ELF and MachO objects.
- add fix-tests-pr-111.patch to skip an optional test depending on third party data
* Thu Sep  7 2017 sebix+novell.com@sebix.at
- update to version 2.4.79
- updated shebang fixes
* Wed Aug 10 2016 sebix+novell.com@sebix.at
- inital package
